@@ -1,5 +1,3 @@
-__version__ = '0.1.0'
-
 import qecstruct as qs
 import multiprocess as mup
 
@@ -65,7 +63,7 @@ class Statistics:
     def __repr__(self):
         string = "Statistics\n"
         string += "----------\n"
-        string += f"number of samples: {self.num_samples()}\n"
+        string += f"number of samples: {self.num_samples}\n"
         if self.sample_size() > 0:
             string += f"failure rate: {self.failure_rate()}\n"
             string += f"success rate: {self.success_rate()}\n"
@@ -104,7 +102,7 @@ class LinearDecodingExperiment:
 
 def convert_to_dataframe(experiment, statistics, extras=dict()):
     data = {
-        "Block length": experiment.code.block_length(),
+        "Block length": len(experiment.code),
         "Dimension": experiment.code.dimension(),
         "Physical error rate": experiment.noise.error_rate(),
         "Number of experiments": statistics.num_experiments(),
